@@ -1113,7 +1113,7 @@ fn parseChunkedBody(chunkedBody: &Vec<u8>) -> Vec<u8> {
     let mut lineSep: Vec<u8> = Vec::new();
     let mut isSizeLine = true;
     for &b in chunkedBody {
-        if b == b'\r' || b == b'\n' || b == b'0' {
+        if b == b'\r' || b == b'\n' {
             lineSep.push(b);
         } else {
             if !isSizeLine {
@@ -1125,6 +1125,9 @@ fn parseChunkedBody(chunkedBody: &Vec<u8>) -> Vec<u8> {
             isSizeLine = false;
         }
     }
+    if body[body.len() - 1] == b'0' {
+        body.pop();
+    }
     body
 }
 
